@@ -1,12 +1,14 @@
 #!/usr/bin/env python
-import sys
 import json
 import logging
-from argparse import ArgumentParser, RawDescriptionHelpFormatter, FileType, SUPPRESS
+import sys
+from argparse import SUPPRESS, ArgumentParser, FileType, RawDescriptionHelpFormatter
 
-from lumapps.api.errors import ApiCallError
-from lumapps.api.utils import list_prune_filters, ConfigStore
-from lumapps.api import ApiClient, TokenClient
+from httpx import HTTPStatusError, RequestError
+
+from lumapps.api import BaseClient, LumAppsClient
+from lumapps.api.errors import BadCallError, get_http_err_content
+from lumapps.api.utils import ConfigStore, list_prune_filters
 
 LIST_CONFIGS = "***LIST_CONFIGS***"
 
@@ -88,9 +90,9 @@ def store_config(api_info, auth_info, conf_name, user=None):
     ConfigStore.set(conf_name, {"api": api_info, "auth": auth_info, "user": user})
 
 
-def cast_params(name_parts, args, api):
+def cast_params(name_parts, args, endpoints):
     truths = ("True", "true", "1", "Yes", "yes", "sure", "yeah")
-    params = api.endpoints[name_parts].get("parameters", {})
+    params = endpoints[name_parts].get("parameters", {})
     for arg in args:
         if params.get(arg, {}).get("type", "") == "boolean":
             args[arg] = args[arg] in truths
@@ -127,13 +129,18 @@ def main():
         proxy_info = None
     api_info, auth_info, user = load_config(args.api, args.auth, args.user, args.config)
     if args.email:
-        token_client = TokenClient(
-            args.customer_id, auth_info, api_info, no_verify=args.no_verify
+        token_client = LumAppsClient(
+            args.customer_id,
+            None,
+            auth_info=auth_info,
+            api_info=api_info,
+            proxy_info=proxy_info,
+            no_verify=args.no_verify,
         )
         token_getter = token_client.get_token_getter(args.email)
     else:
         token_getter = None
-    api = ApiClient(
+    api = BaseClient(
         auth_info,
         api_info,
         user=user,
@@ -167,11 +174,17 @@ def main():
     #     s = args.body.read()
     #     print('will loads this: {}'.format(s))
     #     params['body'] = json.loads(s)
-    cast_params(name_parts, params, api)
+    cast_params(name_parts, params, api.endpoints)
     try:
         response = api.get_call(*name_parts, **params)
-    except ApiCallError as err:
+    except (BadCallError, RequestError) as err:
         sys.exit(err)
+    except HTTPStatusError as err:
+        err_reason = get_http_err_content(err)
+        if err_reason:
+            sys.exit(err_reason)
+        else:
+            sys.exit(err)
     print(json.dumps(response, indent=4, sort_keys=True))
 
 
