@@ -1,4 +1,9 @@
 import os
+from datetime import datetime, timedelta
+from json import dumps, loads
+from typing import Any, Dict, Optional, Sequence
+
+from lumapps.api.conf import __pypi_packagename__
 
 if not os.getenv("GAE_ENV"):  # noqa
     import sqlite3
@@ -7,11 +12,6 @@ if not os.getenv("GAE_ENV"):  # noqa
 else:
     _sqlite_ok = False
 
-from typing import Any, Dict, Optional, Sequence
-from json import loads, dumps
-from datetime import datetime, timedelta
-
-from lumapps.api.conf import __pypi_packagename__
 
 CACHE_MAX_AGE = timedelta(seconds=60 * 60 * 24)  # 1 day
 GOOGLE_APIS = ("drive", "admin", "groupssettings")
@@ -51,7 +51,6 @@ FILTERS = {
     # template/get, template/list, ...
     "template/*": ["properties/duplicateContent"],
     "community/post/*": [
-        "authorDetails",
         "updatedByDetails",
         "mentionsDetails",
         "parentContentDetails",
@@ -157,15 +156,21 @@ class DiscoveryCacheDict:
     def __init__(self):
         self._cache = {}
 
-    def get(self, url):
-        cached = self._cache.get(url)
+    def get(self, key, raises=False):
+        if raises:
+            cached = self._cache[key]
+        else:
+            cached = self._cache.get(key)
         if not cached or cached["expiry"] < datetime.now():
             return None
-        return cached["content"]
+        return cached["value"]
 
-    def set(self, url, content):
-        expiry = datetime.now() + CACHE_MAX_AGE
-        self._cache[url] = {"expiry": expiry, "content": content}
+    def set(self, key, value, ex=None):
+        if ex:
+            expiry = datetime.now() + timedelta(seconds=ex)
+        else:
+            expiry = datetime.now() + CACHE_MAX_AGE
+        self._cache[key] = {"expiry": expiry, "value": value}
 
 
 _DiscoveryCacheDict = DiscoveryCacheDict()
@@ -198,6 +203,7 @@ class DiscoveryCacheSqlite:
         )
 
 
+_discovery_cache: Any
 if _sqlite_ok:
     _discovery_cache = DiscoveryCacheSqlite()
 else:
@@ -230,7 +236,7 @@ def _parse_endpoint_parts(parts):
 
 def method_from_discovery(
     discovery: Dict[str, Any], path: Sequence[str]
-) -> Dict[str, Any]:
+) -> Optional[Dict[str, Any]]:
     for part in path[:-1]:
         discovery = discovery["resources"].get(part)
         if not discovery:
@@ -239,3 +245,15 @@ def method_from_discovery(
         return discovery["methods"][path[-1]]
     except KeyError:
         return None
+
+
+def walk_endpoints(resource, parents=()):
+    for ep_name, ep_info in resource.get("methods", {}).items():
+        yield tuple(parents + (ep_name,)), ep_info
+    for rsc_name, rsc in resource.get("resources", {}).items():
+        for ep_name, ep_info in walk_endpoints(rsc, tuple(parents + (rsc_name,))):
+            yield ep_name, ep_info
+
+
+def get_endpoints(discovery_doc):
+    return {n: m for n, m in walk_endpoints(discovery_doc)}
